import os

from oscars_mgmnt.parser.es.es import ElasticsearchParser


class Sentinel3_Parser(ElasticsearchParser):

    def __init__(self, template=None, es_source_host=None, es_source_index=None):
        super().__init__('CGS_S3.template' if template is None else template, es_source_host, es_source_index)

    def init_dict(self):
        super().init_dict()
        self.dict_info.update(
            {
                "cogProcessingDate": "properties.processing_status.cog_processing_status.processing_end"
            }
        )

    def fix_products(self, fileobject):
        for info in list(fileobject.datas):
            name = os.path.basename(info.name)
            name = name.split('.')[0]
            info.title = os.path.basename(name)
            info.href = "file:///" + info.name
            info.conformsTo = "http://www.opengis.net/def/crs/EPSG/0/4326"


    def specific_treatment(self, product_file_info, values):
        uid = super().specific_treatment(product_file_info, values)
        self.fix_geometry(values, simplify=False)

        values['platformserialid'] = uid.split("_")[0]
        values['conformsto'] = "http://www.opengis.net/def/crs/EPSG/0/4326"
        continent = values['title'][64:81]
        continent = continent.rstrip('_')
        values['productGroupId'] = continent

        if "SY_2_V10___" in values["producttype"]:
            values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S3_SY_2_V10_V1"
            values['compositeType'] = "10-DAILY"
            #values.pop('platformserialid', None)
        elif "SY_2_VG1___" in values["producttype"]:
            values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S3_SY_2_VG1_V1"
            values['compositeType'] = "DAILY"
            #values.pop('platformserialid', None)

        return uid
